import requests
import time
import os
from rich.console import Console
from rich.table import Table

SERPAPI_SHOWTIMES_URL = "https://serpapi.com/search"
SERPAPI_API_KEY = os.getenv("SERPAPI_API_KEY", "your_serpapi_api_key")

default_theater_query = "cinemark century boulder"
default_location = "boulder, colorado, united states"

console = Console()

def get_movie_showtimes():
    params = {
        'q': default_theater_query,
        'hl': 'en',
        'gl': 'us',
        'location': default_location,
        'api_key': SERPAPI_API_KEY
    }
    response = requests.get(SERPAPI_SHOWTIMES_URL, params=params)
    if response.status_code == 200:
        data = response.json()
        return data.get('showtimes', [])
    else:
        raise ValueError("Could not fetch movie showtimes from SerpApi.")

def display_showtimes(showtimes):
    if not showtimes:
        console.print("[bold red]No showtimes available.[/bold red]")
        return
    
    for day_data in showtimes:
        day = day_data.get("day", "Unknown Day")
        console.print(f"\n[bold cyan]{day}[/bold cyan]")
        
        for movie in day_data.get("movies", []):
            table = Table(title=f"{movie['name']}", show_header=True, header_style="bold magenta")
            table.add_column("Type", style="dim")
            table.add_column("Times", justify="right")
            
            for showing in movie.get("showing", []):
                table.add_row(showing["type"], ", ".join(showing["time"]))
            
            console.print(table)

def main():
    showtimes = get_movie_showtimes()
    display_showtimes(showtimes)
    time.sleep(1)

if __name__ == '__main__':
    main()
